/* SAMPLES.C - This file contains a few examples of code from the
               T-Windows DEMO.

              Copyright (c) Oxford Consulting Group, 1989, 1990
  ........................................................................ */



#include "twindows.h"
#include "twindows.pro"
#include "demo.pro"
#include <memcheck.h>

/* ---------------------------------------------------------------
WINDOW_SAMPLES - Overview of simple windows.  This example shows:

                 1. the row/column nature of T-Windows,  and
                 2. define objects in dialog boxes.  */


int window_samples(dsec)
  double (dsec);
{
  int rt, n, row;
  WINDOW *w33;
  static char *para1[] = {
     "Windows: the basic building block of T-Windows",
     " ",
     "The fundamental object of T-Windows is the simple window.  Windows have",
     "attributes such as size, colors, border types, and pointers to other",
     "objects in the window like standard dialog box objects or user defined",
     "objects."
  };

  w33 = define_window();                       /* alloc a window structure */
  if (!w33)
     return(NG);

  w_clearwork();                                   /* clear main work area */
  row = 3;                                                 /* starting row */
  n = sizeof(para1) / sizeof(char *);
  para_out (row, n, para1);                          /* output a paragraph */

  w33->c1 = 2;                              /* simple window: plain border */
  w33->c2 = 17;                     /* define row/column corners of window */
  w33->r1 = 13;
  w33->r2 = 19;
  w33->fg = BLACK;                       /* foreground & background colors */
  w33->bk = LIGHTYELLOW;
  w_open (w33);
  w_puts (w33, 2,4, "Simple");          /* put a string in row 2, col 4... */
  w_puts (w33, 3,4, "Window");
  w_close (w33);

  w33->c1 = 19;                               /* window with shadow border */
  w33->c2 = 34;
  w33->r1 = 13;
  w33->r2 = 20;
  w33->fg = BLACK;
  w33->bk = LIGHTMAGENTA;
  w33->border = SHADOW;
  w_open (w33);
  w_puts (w33, 2,4, "Simple");
  w_puts (w33, 3,4, "Window");
  w_puts (w33, 4,4, " with");
  w_puts (w33, 5,4, "Shadow");
  w_puts (w33, 6,4, "Border");
  w_close (w33);

  w33->c1 = 37;                                  /* window with 3-D border */
  w33->c2 = 52;
  w33->r1 = 13;
  w33->r2 = 20;
  w33->fg = BLUE;
  w33->bk = BRIGHTWHITE;
  w33->border = BORDER_3D;
  w_open (w33);
  w_puts (w33, 2,5, "Simple");
  w_puts (w33, 3,5, "Window");
  w_puts (w33, 4,5, " with ");
  w_puts (w33, 5,5, " 3-D");
  w_puts (w33, 6,5, "Border");
  w_close (w33);

  w33->c1 = 55;             /* window with 3-D border and title box object */
  w33->c2 = 78;
  w33->r1 = 13;
  w33->r2 = 21;
  w33->fg = BLACK;
  w33->bk = WHITE;
  w33->border = BORDER_3D;
  w_open (w33);
  w_puts (w33, 3,5, "Window with");
  w_puts (w33, 4,5, "3-D border");
  w_puts (w33, 5,5, "and a dialog");
  w_puts (w33, 6,5, "box object");

                                     /* define standard dialog box objects */
                                                          /* to the window */
  rt = define_objects (w33, " Title Bar ", NO_SUBTITLE,
                            NO_SUBTEXT, NO_POSITION, YES_CLOSEBOX, OK_BIG,
                            NO_OKSTRING, NO_CANCELSTRING, NO_LIST,
                            NO_COL, NO_SCROLL, NO_STRLN, NO_INSTRING);

  put_objects (w33);                          /* display objects in window */

  w_close(w33);                                 /* close dialog box window */
  free_window (&w33);                       /* free any dialog box objects */
                                                   /* and window structure */

  rt = pauser (dsec);                               /* pauses for n sec or */
                                                   /* returns if kybrd hit */
  return(rt);
}

/* -------------------------------------------------------------------------
PRINT_EXAMPLE - Prints the function list in the background.  This example
                shows:

                 1. Using a standard dialog box, D_STRING
                 2. how easy it is to do background printing  */

void print_example()
{
  int ntext;
  char s[100];
  unsigned int c;
  WINDOW *w10, *w11;
  static char *text[] = {
     "Enter new",
     "filename:"
  };

  w_clearwork();                                        /* clear work area */

  w10 = define_window();                   /* alloc some window structures */
  if (!w10) return;
  w11 = define_window();
  if (!w11) return;

  w11->r1 = 5;
  w11->r2 = 14;
  w11->c1 = 2;
  w11->c2 = 35;
  w11->bk = BRIGHTWHITE;
  w11->fg = BLACK;
  w_open (w11);
  w_putsa (&w1, 6,4,"BACKGROUND PRINTING:",BRIGHTWHITE,LIGHTBLUE);
  w_puts (&w1, 8,4, "Click on OK to print a file");
  w_puts (&w1, 9,4, "that is a list of T-Windows");
  w_puts (&w1, 10,4, "functions or enter your own.");
  w_puts (&w1, 12,4, "FUNCLIST.DOC has the more");
  w_puts (&w1, 13,4, "popular T-Windows functions.");

  w10->image_save = TRUE;                     /* save image behind window. */
                                   /* This lets user drag window around by */
                                   /* clicking & dragging on the title bar */

  w10->r1 = 5;                                      /* set top left corner */
  w10->c1 = 40;

  strcpy (s, "FUNCLIST.DOC");
  ntext = 2;                                  /* # of lines of static text */

  c = d_string (w10, "Background Printing", FALSE, 20, s,
                      text, ntext, OKBOX_TXT, CANCELBOX_TXT);

  if (c == ENTER_KEY)
     t_print_file (s, FALSE, TRUE);            /* print file in background */

  w_close(w10);                  /* close window restoring image behind it */
  free_window(&w10);                  /* free objects and window structure */
  w_close(w11);
  free_window(&w11);                  /* free objects and window structure */
  w_clearwork();                                        /* clear work area */
  return;
}

/* -------------------------------------------------------------------------
SCR_TOP - This is the top level screen for T-Windows.  It handles
          the pull-down menu processing and any routines that will
          run as a result of a menu item being selected.  If the user
          selects another screen level (actually a different screen),
          then this routine returns to main.

              Copyright (c) Oxford Consulting Group, 1989, 1990
  ........................................................................ */


scr_top (scr_levels, level)
   struct screen *scr_levels[];
   int level;
{
  char x_menu, x_item;                          /* 1st char of menu & item */
                                                       /* selected by user */
  int c, rt;
  int i;
  char temp[80];
  char pmt1[120], title[80];
  struct screen *scr;                                   /* ptr to a screen */
  double zip;

  if (!scr_levels[level]) {                                /* sanity check */
     t_error ("SCREEN0: Invalid screen level!");
     return(QUIT);
  }
  zip = 0.0;                                          /* used in demo only */

  ProtectRect (w1.p_rect);
  BackColor (w1.bk);                               /* define window colors */
  PenColor  (w1.fg);
  FillRect (w1.p_rect, w1.pat);                       /* clear everything! */
  ProtectOff ();

  menulines();                                  /* display menubar outline */
  pmt_lines();                                      /* lines around prompt */
  rt = pd_menubar(scr_levels, level);              /* display the menu bar */
  if (rt) {
     sprintf(temp,"Could not display menu bar for screen %d",level);
     t_error (temp);
     return(QUIT);
  }

  scr = scr_levels[level];                                 /* pt to screen */
  if (mouse)
     strcpy (pmt1,
     "Click on the menu bar to pull down a menu or use the big + key (far right) key to pull down a menu (F2: Command Mode)");
  else
     strcpy (pmt1,
     "With the big + key (far right), open a menu. Use arrow keys & ENTER to select an item.");
  strcpy (title, "T-Windows Guided Tour");

  w_prompt (pmt1);                                /* initial screen prompt */
  w_title (title, "");                             /* disp top level title */

  put_in_rt_list (t_status, 17L);    /* start clock as a realtime function */
                                     /* showing on 1st line of status area */

  put_in_rt_list (t_prtscrn, 0L);     /* start a realtime function to look */
                                     /* for the ctrl-PrtScrn key then do a */
                          /* graphics screen dump.  This is a user-written */
                                    /* routine; see prtscrn.c for a sample */

  sprintf (temp, "\nT-Windows Demo");     /* to show any background status */
                                         /* info: Note the newline char to */
                                      /* put it on 2nd line of status area */
  show_stat (temp);

  while (c != QUIT) {
                                              /* get a pull-menu selection */

     rt = get_menu (scr_levels, level, &x_menu, &x_item, &c);

     if (rt == NG || rt == QUIT)               /* bailout if error or QUIT */
        return(QUIT);
     if (rt >= 0 && rt != level)                      /* new screen level? */
        return(rt);                                      /* return to main */

     switch (x_menu) {                           /* switch for menu choice */

        case '(':                          /* T-Windows configuration menu */
        switch (x_item) {
           case 'a':                               /* mouse speed settings */
              set_mouse_speed();
              break;

           case 'b':                       /* save T-Windows configuration */
              save_configs();
              break;
        }
        break;

        case '1':                          /* -------- Intro menu -------- */
        switch (x_item) {
           case 'a':                                  /* pictures overview */
              pictures(zip);
              break;
           case 'b':                                        /* hello world */
              simple_hello_world();
              break;
           case 'c':                                  /* What is T-Windows */
              whatisit(zip);
              break;
           case 'd':                                       /* who uses it? */
              audience(zip);
              break;
           case 'e':                                        /* why use it? */
              why(zip);
              break;
           case 'f':                                     /* how to use it? */
              howto(zip);
              break;
           case 'g':                                /* MetaWINDOW overview */
              metaover();
              break;
           case 'h':                                          /* tech data */
              techdata (zip);
              break;
           case 'i':                           /* scrollable function list */
              funclist ();
              break;
           case 'j':                           /* unsolicited testimonials */
              testimonials();
              break;
           case 'k':
              return(QUIT);                              /* quit T-Windows */
              break;
        }
        break;

        case '2':                 /* -------- T-Windows Utilities -------- */
        switch (x_item) {
           case 'a':                                     /* Sample Windows */
              window_samples(zip);
              break;
           case 'b':                                      /* W_UTILS intro */
              w_utils_intro(zip);
              break;
           case 'c':                                       /* W_UTILS list */
              list_w_utils(zip);
              break;

        ...
        ...
        ... etc.

